# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AttributeSearchConfiguration(Model):
    """AttributeSearchConfiguration.

    :param name: Gets the attribute name.
    :type name: str
    :param properties:
    :type properties:
     ~dynamics.customerinsights.api.models.AttributeSearchProperties
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'properties': {'key': 'properties', 'type': 'AttributeSearchProperties'},
    }

    def __init__(self, *, name: str=None, properties=None, **kwargs) -> None:
        super(AttributeSearchConfiguration, self).__init__(**kwargs)
        self.name = name
        self.properties = properties
