# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiError(Model):
    """ApiError.

    :param error_code: Possible values include: 'notFound',
     'ambiguousReference', 'malformedInput', 'serviceUnavailable',
     'badRequest', 'notAllowed', 'conflict', 'locked', 'forbidden'
    :type error_code: str or ~dynamics.customerinsights.api.models.enum
    :param message:
    :type message: str
    """

    _attribute_map = {
        'error_code': {'key': 'errorCode', 'type': 'str'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ApiError, self).__init__(**kwargs)
        self.error_code = kwargs.get('error_code', None)
        self.message = kwargs.get('message', None)
