# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HistogramBin(Model):
    """Histogram bin.

    :param lower_bound: Gets or sets the lower bound.
    :type lower_bound: float
    :param upper_bound: Gets or sets the upper bound.
    :type upper_bound: float
    :param count: Gets or sets the count.
    :type count: float
    """

    _attribute_map = {
        'lower_bound': {'key': 'lowerBound', 'type': 'float'},
        'upper_bound': {'key': 'upperBound', 'type': 'float'},
        'count': {'key': 'count', 'type': 'float'},
    }

    def __init__(self, *, lower_bound: float=None, upper_bound: float=None, count: float=None, **kwargs) -> None:
        super(HistogramBin, self).__init__(**kwargs)
        self.lower_bound = lower_bound
        self.upper_bound = upper_bound
        self.count = count
