# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class StringLengthCount(Model):
    """StringLengthCount.

    :param length: Gets or sets the string length.
    :type length: long
    :param count: Gets or sets the count of string values with the Length.
    :type count: long
    """

    _attribute_map = {
        'length': {'key': 'length', 'type': 'long'},
        'count': {'key': 'count', 'type': 'long'},
    }

    def __init__(self, **kwargs):
        super(StringLengthCount, self).__init__(**kwargs)
        self.length = kwargs.get('length', None)
        self.count = kwargs.get('count', None)
